@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.2   2006/09/03
+ * Version: 1.3.1   2006/12/08
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -24,8 +24,8 @@
 #define CCS_POLICY_DOMAINPOLICY          0
 #define CCS_POLICY_EXCEPTIONPOLICY       1
 #define CCS_POLICY_SYSTEMPOLICY          2
-#define CCS_INFO_TRUSTEDPIDS             3
-#define CCS_INFO_DELETEDPIDS             4
+#define CCS_POLICY_DOMAIN_STATUS         3
+#define CCS_INFO_PROCESS_STATUS          4
 #define CCS_INFO_MEMINFO                 5
 #define CCS_INFO_GRANTLOG                6
 #define CCS_INFO_REJECTLOG               7
@@ -33,5 +33,7 @@
 #define CCS_INFO_MAPPING                 9
 #define CCS_STATUS                      10
 #define CCS_POLICY_QUERY                11
+#define CCS_POLICY_MANAGER              12
+#define CCS_INFO_UPDATESCOUNTER         13
 
 #endif
