@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.1.2   2006/06/02
+ * Version: 1.3.1   2006/12/08
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -23,9 +23,9 @@ void ROFS_Log_from_dentry(struct dentry *dentry, struct vfsmount *mnt, const cha
 {
 	char *buffer;
 	if (!CheckCCSFlags(CCS_SAKURA_TRACE_READONLY)) return;
-	if ((buffer = kzalloc(PAGE_SIZE, GFP_KERNEL)) == NULL) return;
+	if ((buffer = ccs_alloc(PAGE_SIZE)) == NULL) return;
 	if (realpath_from_dentry(dentry, mnt, buffer, PAGE_SIZE - 1) == 0) printk("ReadOnly:%s:%s\n", how, buffer);
-	kfree(buffer);
+	ccs_free(buffer);
 }
 
 void ROFS_Log(const char *filename, const char *how)
@@ -34,7 +34,7 @@ void ROFS_Log(const char *filename, const char *how)
 	if (!CheckCCSFlags(CCS_SAKURA_TRACE_READONLY)) return;
 	if ((buffer = realpath(filename)) == NULL) return;
 	printk("ReadOnly:%s:%s\n", how, buffer);
-	kfree(buffer);
+	ccs_free(buffer);
 }
 
 EXPORT_SYMBOL(ROFS_Log_from_dentry);
