@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.2   2006/09/03
+ * Version: 1.3.1   2006/12/08
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -61,12 +61,14 @@ int WriteAuditLog(char *buf, const int is_granted)
 			list_add_tail(&new_entry->list, &grant_log);
 			grant_log_count++;
 			buf = NULL;
+			UpdateCounter(CCS_UPDATES_COUNTER_GRANT_LOG);
 		}
 	} else {
 		if (reject_log_count < GetMaxRejectLog()) {
 			list_add_tail(&new_entry->list, &reject_log);
 			reject_log_count++;
 			buf = NULL;
+			UpdateCounter(CCS_UPDATES_COUNTER_REJECT_LOG);
 		}
 	}
 	spin_unlock(&audit_log_lock);
